@@ -1,16 +1,16 @@
 """ Main module for the Discord bot application. """
 
 import sys
-from typing import Callable, List, Optional, Type
+from typing import Callable, Optional, Sequence, Type
 
-from spectra_lexer import SpectraOptions
-from spectra_lexer.analysis import StenoAnalyzer, TranslationPairs
+from spectra_lexer import Spectra, SpectraOptions
 from spectra_lexer.console.system import SystemConsole
-from spectra_lexer.discord import DiscordMessage, DiscordBot
-from spectra_lexer.display import BoardDiagram, BoardEngine
 from spectra_lexer.qt.svg import SVGRasterEngine
 from spectra_lexer.resource.rules import StenoRule
-from spectra_lexer.search import SearchEngine
+from spectra_lexer.spc_board import BoardDiagram, BoardEngine
+from spectra_lexer.spc_lexer import StenoAnalyzer, TranslationPairs
+from spectra_lexer.spc_search import SearchEngine
+from spectra_lexer.util.discord import DiscordBot, DiscordMessage
 
 
 class MessageFactory:
@@ -51,11 +51,11 @@ class DiscordApplication:
         self._search_depth = search_depth        # Maximum number of search results to analyze at once.
         self._board_AR = board_AR                # Optional fixed aspect ratio for board images.
 
-    def _find_matches(self, word:str) -> List[str]:
+    def _find_matches(self, word:str) -> Sequence[str]:
         """ Search for possible stroke matches for a <word>. """
         matches = self._search_engine.search(word, self._search_depth)
         if not matches:
-            return []
+            return ()
         if word in matches:
             return matches[word]
         key = word.lower()
@@ -64,7 +64,7 @@ class DiscordApplication:
         for m in matches:
             if key == m.lower():
                 return matches[m]
-        return []
+        return ()
 
     def _best_translation(self, word:str) -> str:
         """ Find the best pairing between a word and its possible stroke matches. """
@@ -139,20 +139,18 @@ class DiscordApplication:
         return bot.run()
 
 
-def build_app(opts:SpectraOptions) -> DiscordApplication:
-    spectra = opts.compile()
-    translations_files = opts.translations_paths()
-    log = spectra.log
-    io = spectra.translations_io
+def build_app(spectra:Spectra) -> DiscordApplication:
+    io = spectra.resource_io
     search_engine = spectra.search_engine
     analyzer = spectra.analyzer
     board_engine = spectra.board_engine
+    log = spectra.logger.log
     log("Loading...")
     svg_engine = SVGRasterEngine(background_rgba=(0, 0, 0, 0))
     msg_factory = MessageFactory(svg_engine=svg_engine)
     excluded_chars = r'''#$%&()*+-,.?!/:;<=>@[\]^_`"{|}~'''
     map_to_space = dict.fromkeys(map(ord, excluded_chars), ' ')
-    translations = io.load_json_translations(*translations_files)
+    translations = io.load_json_translations(*spectra.translations_paths)
     # Strip Plover glue and case metacharacters so our search engine has a chance to find the actual text.
     stripped_values = [v.strip(' {<&>}') for v in translations.values()]
     translations = {k: v for k, v in zip(translations, stripped_values) if v}
@@ -164,7 +162,8 @@ def build_app(opts:SpectraOptions) -> DiscordApplication:
 def main() -> int:
     opts = SpectraOptions("Run Spectra as a Discord bot.")
     opts.add("token", "", "Discord bot token (REQUIRED).")
-    app = build_app(opts)
+    spectra = Spectra.compile(opts)
+    app = build_app(spectra)
     return app.run_bot(opts.token)
 
 
