@@ -2,7 +2,7 @@
 
 from typing import Any
 
-from spectra_lexer import SpectraOptions
+from spectra_lexer import Spectra
 from spectra_lexer.gui_engine import GUIEngine
 from spectra_lexer.gui_ext import GUIExtension
 from spectra_lexer.gui_qt import build_app, QtGUIApplication
@@ -22,8 +22,7 @@ class PloverPluginApplication:
         """ The startup translations come from the current Plover dictionaries. """
         translations = self._plover_ext.parse_engine_dictionaries()
         self._gui_ext.set_translations(translations)
-        self._gui_ext.load_start_examples()
-        self._gui_ext.load_config()
+        self._gui_ext.load_initial()
 
     def _load_translations(self, steno_dc:IPlover.StenoDictionaryCollection) -> None:
         translations = self._plover_ext.parse_dictionaries(steno_dc)
@@ -41,7 +40,8 @@ class PloverPluginApplication:
         translation = self._plover_ext.parse_actions(*args)
         if translation is not None and not self._app.has_focus():
             keys, letters = translation
-            self._app.gui_query(keys, letters, strict=False)
+            self._app.set_options(lexer_strict_mode=False)
+            self._app.gui_query(keys, letters)
 
     def start(self) -> None:
         """ Start the main app and connect the Plover extension only if compatible. """
@@ -84,15 +84,20 @@ class PloverPlugin:
 
     def __init__(self, plover_engine:IPlover.Engine) -> None:
         """ Main entry point for Spectra's Plover plugin. The Plover engine is our only argument.
-            Command-line arguments are not used (sys.argv belongs to Plover).
+            Command-line arguments are not used (sys.argv belongs to Plover), and translations are not read from files.
             We create the main application object, but do not expose it except through __getattr__. """
-        opts = SpectraOptions()
-        spectra = opts.compile(parse_args=False)
-        index_path = opts.index_path()
-        cfg_path = opts.config_path()
-        gui_engine = GUIEngine(spectra.search_engine, spectra.analyzer, spectra.graph_engine, spectra.board_engine)
-        gui_ext = GUIExtension(spectra.translations_io, spectra.search_engine, spectra.analyzer, index_path, cfg_path)
-        app = build_app(gui_engine, gui_ext, spectra.log)
+        spectra = Spectra.compile(parse_args=False)
+        io = spectra.resource_io
+        search_engine = spectra.search_engine
+        analyzer = spectra.analyzer
+        graph_engine = spectra.graph_engine
+        board_engine = spectra.board_engine
+        log = spectra.logger.log
+        index_path = spectra.index_path
+        cfg_path = spectra.cfg_path
+        gui_engine = GUIEngine(search_engine, analyzer, graph_engine, board_engine)
+        gui_ext = GUIExtension(io, search_engine, analyzer, (), index_path, cfg_path)
+        app = build_app(gui_engine, gui_ext, log)
         plover_ext = PloverExtension(EngineWrapper(plover_engine), stroke_limit=self.STROKE_LIMIT)
         # Add the extension as an app attribute so it is visible to the Qt app debug tools.
         app.plover = plover_ext
