@@ -1,10 +1,11 @@
-""" Module for rendering text graphs in grid form and formatting them into user-readable strings with markup. """
+""" HTML formatter for grids of text elements with markup. """
 
 from functools import lru_cache
+from typing import Sequence
 
-from .base import TextElementGrid
+from . import TextElement
 
-GRAPH_CSS_CLASS = "stenoGraph"
+TextElementGrid = Sequence[Sequence[TextElement]]  # Indexable 2D grid of text elements.
 
 
 class HTMLFormat:
@@ -18,6 +19,8 @@ class HTMLFormat:
         self.stylesheet = stylesheet  # CSS stylesheet. Required to stop anchors from behaving as hyperlinks.
 
 
+GRAPH_CSS_CLASS = "stenoGraph"
+
 # Formats text using preformatted whitespace with normal line breaks.
 # Adds additional styles needed for monospacing.
 STANDARD_FORMAT = HTMLFormat(
